@@ -35,6 +35,10 @@ class GenericAPI:
         self._auth = auth
         self._base_url = auth.get_base_url().rstrip('/')
 
+    @property
+    def auth(self):
+        return self._auth
+
     def _report_api_error(self, response):
         """
         Report an error from an API call.
