@@ -1,3 +1,5 @@
+from functools import partial
+
 import requests
 
 from .base import GenericAPI, ERROR_THRESHOLD
@@ -21,12 +23,14 @@ class MetatronAPI(GenericAPI):
 
     def get_parsers(self):
         """Get information on parsers available to the current user."""
-        r = requests.get(
+        curried_request = partial(
+            requests.get,
             url=f'{self._base_url}/api/metatron/parsers/',
             headers=self._auth.get_headers(),
             cookies=self._auth.get_cookies(),
-            verify=False,
+            verify=self._auth.verify,
         )
+        r = self.attempt_api_call(curried_request=curried_request)
 
         if r.status_code < ERROR_THRESHOLD:
             return r.json()
