@@ -27,7 +27,7 @@ class ProjectsAPI(GenericAPI):
             url='{}/api/projects/project/'.format(self._auth.get_base_url()),
             headers=self._auth.get_headers(),
             cookies=self._auth.get_cookies(),
-            verify=False,
+            verify=self.auth.verify,
         )
 
         if r.status_code < ERROR_THRESHOLD:
